@@ -1,7 +1,7 @@
 #This file is part of Tryton.  The COPYRIGHT file at the top level of
 #this repository contains the full copyright notices and license terms.
 from trytond.model import ModelView, ModelSQL, fields
-from trytond.wizard import Wizard
+from trytond.wizard import Wizard, StateTransition
 from trytond.backend import TableHandler
 from trytond.pyson import Eval, Bool
 from trytond.transaction import Transaction
@@ -56,8 +56,8 @@ class Column(ModelSQL, ModelView):
     name = fields.Char('Name', size=None, required=True)
     field = fields.Many2One('ir.model.field', 'Field', required=True,
             domain=[('model.model', '=', 'account.move.line')])
-    view = fields.Many2One('account.journal.view', 'View', select=1)
-    sequence = fields.Integer('Sequence', select=2)
+    view = fields.Many2One('account.journal.view', 'View', select=True)
+    sequence = fields.Integer('Sequence', select=True, required=True)
     required = fields.Boolean('Required')
     readonly = fields.Boolean('Readonly')
 
@@ -81,7 +81,7 @@ class Journal(ModelSQL, ModelView):
 
     name = fields.Char('Name', size=None, required=True, translate=True)
     code = fields.Char('Code', size=None)
-    active = fields.Boolean('Active', select=2)
+    active = fields.Boolean('Active', select=True)
     type = fields.Selection('get_types', 'Type', required=True)
     view = fields.Many2One('account.journal.view', 'View')
     centralised = fields.Boolean('Centralised counterpart')
@@ -127,7 +127,7 @@ class Journal(ModelSQL, ModelView):
         # Migration from 1.0 sequence Many2One change into Property
         if table.column_exist('sequence'):
             property_obj = Pool().get('ir.property')
-            cursor.execute('SELECT id, sequence FROM "' + self._table +'"')
+            cursor.execute('SELECT id, sequence FROM "' + self._table + '"')
             with Transaction().set_user(0):
                 for journal_id, sequence_id in cursor.fetchall():
                     property_obj.set('sequence', self._name,
@@ -145,7 +145,7 @@ class Journal(ModelSQL, ModelView):
         return False
 
     def default_sequence(self):
-        return False
+        return None
 
     def get_types(self):
         type_obj = Pool().get('account.journal.type')
@@ -175,7 +175,8 @@ class Period(ModelSQL, ModelView):
     period = fields.Many2One('account.period', 'Period', required=True,
             ondelete='CASCADE', states=STATES, depends=DEPENDS)
     icon = fields.Function(fields.Char('Icon'), 'get_icon')
-    active = fields.Boolean('Active', select=2, states=STATES, depends=DEPENDS)
+    active = fields.Boolean('Active', select=True, states=STATES,
+        depends=DEPENDS)
     state = fields.Selection([
         ('open', 'Open'),
         ('close', 'Close'),
@@ -252,48 +253,38 @@ class Period(ModelSQL, ModelView):
             'state': 'close',
             })
 
+    def open_(self, ids):
+        "Open journal - period"
+        self.write(ids, {
+                'state': 'open',
+                })
+
 Period()
 
 
 class ClosePeriod(Wizard):
     'Close Journal - Period'
-    _name = 'account.journal.close_period'
-    states = {
-        'init': {
-            'actions': ['_close'],
-            'result': {
-                'type': 'state',
-                'state': 'end',
-            },
-        },
-    }
+    _name = 'account.journal.period.close'
+    start_state = 'close'
+    close = StateTransition()
 
-    def _close(self, data):
+    def transition_close(self, session):
         journal_period_obj = Pool().get('account.journal.period')
-        journal_period_obj.close(data['ids'])
-        return {}
+        journal_period_obj.close(Transaction().context['active_ids'])
+        return 'end'
 
 ClosePeriod()
 
 
 class ReOpenPeriod(Wizard):
     'Re-Open Journal - Period'
-    _name = 'account.journal.reopen_period'
-    states = {
-        'init': {
-            'actions': ['_reopen'],
-            'result': {
-                'type': 'state',
-                'state': 'end',
-            },
-        },
-    }
+    _name = 'account.journal.period.reopen'
+    start_state = 'reopen'
+    reopen = StateTransition()
 
-    def _reopen(self, data):
+    def transition_reopen(self, session):
         journal_period_obj = Pool().get('account.journal.period')
-        journal_period_obj.write(data['ids'], {
-            'state': 'open',
-            })
-        return {}
+        journal_period_obj.open_(Transaction().context['active_ids'])
+        return 'end'
 
 ReOpenPeriod()
