@@ -1,13 +1,15 @@
 #This file is part of Tryton.  The COPYRIGHT file at the top level of
 #this repository contains the full copyright notices and license terms.
 from trytond.model import ModelView, ModelSQL, fields, OPERATORS
-from trytond.wizard import Wizard
-from trytond.pyson import Equal, Eval
+from trytond.wizard import Wizard, StateTransition
+from trytond.pyson import Eval
 from trytond.transaction import Transaction
+from trytond.pool import Pool
 
 _STATES = {
-    'readonly': Equal(Eval('state'), 'close'),
+    'readonly': Eval('state') == 'close',
 }
+_DEPENDS = ['state']
 
 
 class Period(ModelSQL, ModelView):
@@ -18,24 +20,27 @@ class Period(ModelSQL, ModelView):
     name = fields.Char('Name', required=True)
     code = fields.Char('Code')
     start_date = fields.Date('Starting Date', required=True, states=_STATES,
-            select=1)
+        depends=_DEPENDS, select=True)
     end_date = fields.Date('Ending Date', required=True, states=_STATES,
-            select=1)
+        depends=_DEPENDS, select=True)
     fiscalyear = fields.Many2One('account.fiscalyear', 'Fiscal Year',
-            required=True, states=_STATES, select=1)
+        required=True, states=_STATES, depends=_DEPENDS, select=True)
     state = fields.Selection([
         ('open', 'Open'),
         ('close', 'Close'),
         ], 'State', readonly=True, required=True)
-    post_move_sequence =fields.Many2One('ir.sequence', 'Post Move Sequence',
-            required=True, domain=[('code', '=', 'account.move')],
-            context={'code': 'account.move'}, states={
+    post_move_sequence = fields.Many2One('ir.sequence', 'Post Move Sequence',
+        required=True, domain=[('code', '=', 'account.move')],
+        context={'code': 'account.move'}, states={
             'required': False,
             })
     type = fields.Selection([
-        ('standard', 'Standard'),
-        ('adjustment', 'Adjustment'),
-        ], 'Type', required=True, states=_STATES, select=1)
+            ('standard', 'Standard'),
+            ('adjustment', 'Adjustment'),
+            ], 'Type', required=True,
+        states=_STATES, depends=_DEPENDS, select=True)
+    company = fields.Function(fields.Many2One('company.company', 'Company',),
+        'get_company', searcher='search_company')
 
     def __init__(self):
         super(Period, self).__init__()
@@ -72,6 +77,15 @@ class Period(ModelSQL, ModelView):
     def default_type(self):
         return 'standard'
 
+    def get_company(self, ids, name):
+        result = {}
+        for period in self.browse(ids):
+            result[period.id] = period.fiscalyear.company.id
+        return result
+
+    def search_company(self, name, clause):
+        return [('fiscalyear.%s' % name,) + tuple(clause[1:])]
+
     def check_dates(self, ids):
         cursor = Transaction().cursor
         for period in self.browse(ids):
@@ -124,9 +138,9 @@ class Period(ModelSQL, ModelView):
         :param date: the date searched
         :param exception: a boolean to raise or not an exception
         :param test_state: a boolean if true will search on non-closed periods
-        :return: the period id found or False
+        :return: the period id found or None
         '''
-        date_obj = self.pool.get('ir.date')
+        date_obj = Pool().get('ir.date')
 
         if not date:
             date = date_obj.today()
@@ -143,11 +157,11 @@ class Period(ModelSQL, ModelView):
             if exception:
                 self.raise_user_error('no_period_date')
             else:
-                return False
+                return None
         return ids[0]
 
     def _check(self, ids):
-        move_obj = self.pool.get('account.move')
+        move_obj = Pool().get('account.move')
         if isinstance(ids, (int, long)):
             ids = [ids]
         move_ids = move_obj.search([
@@ -160,6 +174,7 @@ class Period(ModelSQL, ModelView):
     def search(self, args, offset=0, limit=None, order=None, count=False,
             query_string=False):
         args = args[:]
+
         def process_args(args):
             i = 0
             while i < len(args):
@@ -173,7 +188,8 @@ class Period(ModelSQL, ModelView):
                         args[i] = ('id', '!=', '0')
                     else:
                         period = self.browse(args[i][2][0])
-                        args[i] = (args[i][0], args[i][1], period[args[i][2][1]])
+                        args[i] = (args[i][0], args[i][1],
+                            period[args[i][2][1]])
                 elif isinstance(args[i], list):
                     process_args(args[i])
                 i += 1
@@ -182,7 +198,7 @@ class Period(ModelSQL, ModelView):
                 order=order, count=count, query_string=query_string)
 
     def create(self, vals):
-        fiscalyear_obj = self.pool.get('account.fiscalyear')
+        fiscalyear_obj = Pool().get('account.fiscalyear')
         vals = vals.copy()
         if vals.get('fiscalyear'):
             fiscalyear = fiscalyear_obj.browse(vals['fiscalyear'])
@@ -193,7 +209,7 @@ class Period(ModelSQL, ModelView):
         return super(Period, self).create(vals)
 
     def write(self, ids, vals):
-        move_obj = self.pool.get('account.move')
+        move_obj = Pool().get('account.move')
         for key in vals.keys():
             if key in ('start_date', 'end_date', 'fiscalyear'):
                 self._check(ids)
@@ -219,8 +235,8 @@ class Period(ModelSQL, ModelView):
         return super(Period, self).delete(ids)
 
     def close(self, ids):
-        journal_period_obj = self.pool.get('account.journal.period')
-        move_obj = self.pool.get('account.move')
+        journal_period_obj = Pool().get('account.journal.period')
+        move_obj = Pool().get('account.move')
 
         if isinstance(ids, (int, long)):
             ids = [ids]
@@ -240,48 +256,38 @@ class Period(ModelSQL, ModelView):
             ])
         journal_period_obj.close(journal_period_ids)
 
+    def open_(self, ids):
+        "Open Journal"
+        self.write(ids, {
+                'state': 'open',
+                })
+
 Period()
 
 
 class ClosePeriod(Wizard):
     'Close Period'
-    _name = 'account.period.close_period'
-    states = {
-        'init': {
-            'actions': ['_close'],
-            'result': {
-                'type': 'state',
-                'state': 'end',
-            },
-        },
-    }
+    _name = 'account.period.close'
+    start_state = 'close'
+    close = StateTransition()
 
-    def _close(self, data):
-        period_obj = self.pool.get('account.period')
-        period_obj.close(data['ids'])
-        return {}
+    def transition_close(self, session):
+        period_obj = Pool().get('account.period')
+        period_obj.close(Transaction().context['active_ids'])
+        return 'end'
 
 ClosePeriod()
 
 
 class ReOpenPeriod(Wizard):
     'Re-Open Period'
-    _name = 'account.period.reopen_period'
-    states = {
-        'init': {
-            'actions': ['_reopen'],
-            'result': {
-                'type': 'state',
-                'state': 'end',
-            },
-        },
-    }
+    _name = 'account.period.reopen'
+    start_state = 'reopen'
+    reopen = StateTransition()
 
-    def _reopen(self, data):
-        period_obj = self.pool.get('account.period')
-        period_obj.write(data['ids'], {
-            'state': 'open',
-            })
-        return {}
+    def transition_reopen(self, session):
+        period_obj = Pool().get('account.period')
+        period_obj.open_(Transaction().context['active_ids'])
+        return 'end'
 
 ReOpenPeriod()
