@@ -2,12 +2,13 @@
 #this repository contains the full copyright notices and license terms.
 from decimal import Decimal
 from trytond.model import ModelView, ModelSQL, fields
-from trytond.wizard import Wizard
+from trytond.wizard import Wizard, StateView, StateAction, Button
 from trytond.backend import TableHandler
 from trytond.pyson import Eval, If, Bool, PYSONEncoder
 from trytond.transaction import Transaction
 from trytond.cache import Cache
 from trytond.pool import Pool
+from trytond.config import CONFIG
 
 
 class Group(ModelSQL, ModelView):
@@ -39,7 +40,7 @@ class CodeTemplate(ModelSQL, ModelView):
     parent = fields.Many2One('account.tax.code.template', 'Parent')
     childs = fields.One2Many('account.tax.code.template', 'parent', 'Children')
     account = fields.Many2One('account.account.template', 'Account Template',
-            domain=[('parent', '=', False)], required=True)
+            domain=[('parent', '=', None)], required=True)
     description = fields.Text('Description', translate=True)
 
     def __init__(self):
@@ -73,7 +74,7 @@ class CodeTemplate(ModelSQL, ModelView):
         return res
 
     def create_tax_code(self, template, company_id, template2tax_code=None,
-            parent_id=False):
+            parent_id=None):
         '''
         Create recursively tax codes based on template.
 
@@ -104,7 +105,7 @@ class CodeTemplate(ModelSQL, ModelView):
 
             new_id = tax_code_obj.create(vals)
 
-            prev_lang = template._context.get('language') or 'en_US'
+            prev_lang = template._context.get('language') or CONFIG['language']
             prev_data = {}
             for field_name, field in template._columns.iteritems():
                 if getattr(field, 'translate', False):
@@ -140,12 +141,13 @@ class Code(ModelSQL, ModelView):
     _name = 'account.tax.code'
     _description = __doc__
 
-    name = fields.Char('Name', size=None, required=True, select=1,
+    name = fields.Char('Name', size=None, required=True, select=True,
                        translate=True)
-    code = fields.Char('Code', size=None, select=1)
-    active = fields.Boolean('Active', select=2)
-    company = fields.Many2One('company.company', 'Company', required=True)
-    parent = fields.Many2One('account.tax.code', 'Parent', select=1,
+    code = fields.Char('Code', size=None, select=True)
+    active = fields.Boolean('Active', select=True)
+    company = fields.Many2One('company.company', 'Company', required=True,
+        select=True)
+    parent = fields.Many2One('account.tax.code', 'Parent', select=True,
             domain=[('company', '=', Eval('company', 0))], depends=['company'])
     childs = fields.One2Many('account.tax.code', 'parent', 'Children',
             domain=[('company', '=', Eval('company', 0))], depends=['company'])
@@ -171,7 +173,7 @@ class Code(ModelSQL, ModelView):
         return True
 
     def default_company(self):
-        return Transaction().context.get('company') or False
+        return Transaction().context.get('company')
 
     def on_change_with_currency_digits(self, vals):
         company_obj = Pool().get('company.company')
@@ -195,18 +197,17 @@ class Code(ModelSQL, ModelView):
         child_ids = self.search([('parent', 'child_of', ids)])
         all_ids = {}.fromkeys(ids + child_ids).keys()
         line_query, _ = move_line_obj.query_get()
-        cursor.execute('SELECT c.id, ' \
-                    'SUM(tl.amount) ' \
-                'FROM account_tax_code c, ' \
-                    'account_tax_line tl, ' \
-                    'account_move_line l ' \
-                'WHERE c.id = tl.code ' \
-                    'AND tl.move_line = l.id ' \
-                    'AND c.id IN (' + \
-                        ','.join(('%s',) * len(all_ids))+ ') ' \
-                    'AND ' + line_query + ' ' \
-                    'AND c.active ' \
-                'GROUP BY c.id', all_ids)
+        cursor.execute('SELECT c.id, SUM(tl.amount) '
+            'FROM account_tax_code c, '
+                'account_tax_line tl, '
+                'account_move_line l '
+            'WHERE c.id = tl.code '
+                'AND tl.move_line = l.id '
+                'AND c.id IN (' +
+                    ','.join(('%s',) * len(all_ids)) + ') '
+                'AND ' + line_query + ' '
+                'AND c.active '
+            'GROUP BY c.id', all_ids)
         code_sum = {}
         for code_id, sum in cursor.fetchall():
             # SQLite uses float for SUM
@@ -274,7 +275,7 @@ class Code(ModelSQL, ModelView):
             if vals:
                 self.write(code.id, vals)
 
-            prev_lang = code._context.get('language') or 'en_US'
+            prev_lang = code._context.get('language') or CONFIG['language']
             prev_data = {}
             for field_name, field in code.template._columns.iteritems():
                 if getattr(field, 'translate', False):
@@ -301,9 +302,9 @@ class Code(ModelSQL, ModelView):
 Code()
 
 
-class OpenChartCodeInit(ModelView):
-    'Open Chart Code Init'
-    _name = 'account.tax.open_chart_code.init'
+class OpenChartTaxCodeStart(ModelView):
+    'Open Chart of Tax Codes'
+    _name = 'account.tax.code.open_chart.start'
     _description = __doc__
     method = fields.Selection([
         ('fiscalyear', 'By Fiscal Year'),
@@ -323,48 +324,35 @@ class OpenChartCodeInit(ModelView):
     def default_method(self):
         return 'periods'
 
-OpenChartCodeInit()
+OpenChartTaxCodeStart()
 
 
-class OpenChartCode(Wizard):
-    'Open Chart Of Tax Code by Fiscal Year'
-    _name = 'account.tax.open_chart_code'
-    states = {
-        'init': {
-            'result': {
-                'type': 'form',
-                'object': 'account.tax.open_chart_code.init',
-                'state': [
-                    ('end', 'Cancel', 'tryton-cancel'),
-                    ('open', 'Open', 'tryton-ok', True),
-                ],
-            },
-        },
-        'open': {
-            'result': {
-                'type': 'action',
-                'action': '_action_open_chart',
-                'state': 'end',
-            },
-        },
-    }
+class OpenChartTaxCode(Wizard):
+    'Open Chart of Tax Codes'
+    _name = 'account.tax.code.open_chart'
 
-    def _action_open_chart(self, data):
-        model_data_obj = Pool().get('ir.model.data')
-        act_window_obj = Pool().get('ir.action.act_window')
-        act_window_id = model_data_obj.get_id('account', 'act_tax_code_tree2')
-        res = act_window_obj.read(act_window_id)
-        if data['form']['method'] == 'fiscalyear':
-            res['pyson_context'] = PYSONEncoder().encode({
-                'fiscalyear': data['form']['fiscalyear'],
-            })
+    start = StateView('account.tax.code.open_chart.start',
+        'account.tax_code_open_chart_start_view_form', [
+            Button('Cancel', 'end', 'tryton-cancel'),
+            Button('Open', 'open_', 'tryton-ok', default=True),
+            ])
+    open_ = StateAction('account.act_tax_code_tree2')
+
+    def do_open_(self, session, action):
+        if session.start.method == 'fiscalyear':
+            action['pyson_context'] = PYSONEncoder().encode({
+                    'fiscalyear': session.start.fiscalyear.id,
+                    })
         else:
-            res['pyson_context'] = PYSONEncoder().encode({
-                'periods': data['form']['periods'][0][1],
-            })
-        return res
+            action['pyson_context'] = PYSONEncoder().encode({
+                    'periods': [x.id for x in session.start.periods],
+                    })
+        return action, {}
 
-OpenChartCode()
+    def transition_open_(self, session):
+        return 'end'
+
+OpenChartTaxCode()
 
 
 class TaxTemplate(ModelSQL, ModelView):
@@ -375,7 +363,7 @@ class TaxTemplate(ModelSQL, ModelView):
     name = fields.Char('Name', required=True, translate=True)
     description = fields.Char('Description', required=True, translate=True)
     group = fields.Many2One('account.tax.group', 'Group')
-    sequence = fields.Integer('Sequence')
+    sequence = fields.Integer('Sequence', required=True)
     amount = fields.Numeric('Amount', digits=(16, 8))
     percentage = fields.Numeric('Percentage', digits=(16, 8))
     type = fields.Selection([
@@ -397,12 +385,14 @@ class TaxTemplate(ModelSQL, ModelView):
     invoice_tax_sign = fields.Numeric('Invoice Tax Sign', digits=(2, 0))
     credit_note_base_code = fields.Many2One('account.tax.code.template',
             'Credit Note Base Code')
-    credit_note_base_sign = fields.Numeric('Credit Note Base Sign', digits=(2, 0))
+    credit_note_base_sign = fields.Numeric('Credit Note Base Sign',
+        digits=(2, 0))
     credit_note_tax_code = fields.Many2One('account.tax.code.template',
             'Credit Note Tax Code')
-    credit_note_tax_sign = fields.Numeric('Credit Note Tax Sign', digits=(2, 0))
+    credit_note_tax_sign = fields.Numeric('Credit Note Tax Sign',
+        digits=(2, 0))
     account = fields.Many2One('account.account.template', 'Account Template',
-            domain=[('parent', '=', False)], required=True)
+            domain=[('parent', '=', None)], required=True)
 
     def __init__(self):
         super(TaxTemplate, self).__init__()
@@ -457,7 +447,7 @@ class TaxTemplate(ModelSQL, ModelView):
         return res
 
     def create_tax(self, template, company_id, template2tax_code,
-            template2account, template2tax=None, parent_id=False):
+            template2account, template2tax=None, parent_id=None):
         '''
         Create recursively taxes based on template.
 
@@ -465,8 +455,8 @@ class TaxTemplate(ModelSQL, ModelView):
                 used for tax creation
         :param company_id: the id of the company for which taxes are created
         :param template2tax_code: a dictionary with tax code template id as key
-                and tax code id as value, used to convert tax code template into
-                tax code
+                and tax code id as value, used to convert tax code template
+                into tax code
         :param template2account: a dictionary with account template id as key
                 and account id as value, used to convert account template into
                 account code
@@ -494,36 +484,36 @@ class TaxTemplate(ModelSQL, ModelView):
                 vals['invoice_account'] = \
                         template2account[template.invoice_account.id]
             else:
-                vals['invoice_account'] =  False
+                vals['invoice_account'] = None
             if template.credit_note_account:
                 vals['credit_note_account'] = \
                         template2account[template.credit_note_account.id]
             else:
-                vals['credit_note_account'] = False
+                vals['credit_note_account'] = None
             if template.invoice_base_code:
                 vals['invoice_base_code'] = \
                         template2tax_code[template.invoice_base_code.id]
             else:
-                vals['invoice_base_code'] = False
+                vals['invoice_base_code'] = None
             if template.invoice_tax_code:
                 vals['invoice_tax_code'] = \
                         template2tax_code[template.invoice_tax_code.id]
             else:
-                vals['invoice_tax_code'] = False
+                vals['invoice_tax_code'] = None
             if template.credit_note_base_code:
                 vals['credit_note_base_code'] = \
                         template2tax_code[template.credit_note_base_code.id]
             else:
-                vals['credit_note_base_code'] = False
+                vals['credit_note_base_code'] = None
             if template.credit_note_tax_code:
                 vals['credit_note_tax_code'] = \
                         template2tax_code[template.credit_note_tax_code.id]
             else:
-                vals['credit_note_tax_code'] = False
+                vals['credit_note_tax_code'] = None
 
             new_id = tax_obj.create(vals)
 
-            prev_lang = template._context.get('language') or 'en_US'
+            prev_lang = template._context.get('language') or CONFIG['language']
             prev_data = {}
             for field_name, field in template._columns.iteritems():
                 if getattr(field, 'translate', False):
@@ -575,17 +565,19 @@ class Tax(ModelSQL, ModelView):
                 'invisible': Bool(Eval('parent')),
             }, depends=['parent'])
     active = fields.Boolean('Active')
-    sequence = fields.Integer('Sequence',
+    sequence = fields.Integer('Sequence', required=True,
             help='Use to order the taxes')
     currency_digits = fields.Function(fields.Integer('Currency Digits',
         on_change_with=['company']), 'get_currency_digits')
     amount = fields.Numeric('Amount', digits=(16, Eval('currency_digits', 2)),
         states={
+            'required': Eval('type') == 'fixed',
             'invisible': Eval('type') != 'fixed',
             }, help='In company\'s currency',
         depends=['type', 'currency_digits'])
     percentage = fields.Numeric('Percentage', digits=(16, 8),
         states={
+            'required': Eval('type') == 'percentage',
             'invisible': Eval('type') != 'percentage',
             }, help='In %', depends=['type'])
     type = fields.Selection([
@@ -599,21 +591,22 @@ class Tax(ModelSQL, ModelView):
         domain=[
             ('id', If(Eval('context', {}).contains('company'), '=', '!='),
                 Eval('context', {}).get('company', 0)),
-            ])
+            ], select=True)
     invoice_account = fields.Many2One('account.account', 'Invoice Account',
         domain=[
             ('company', '=', Eval('company')),
-            ('kind', '!=', 'view'),
+            ('kind', 'not in', ['view', 'receivable', 'payable']),
             ],
         states={
             'readonly': (Eval('type') == 'none') | ~Eval('company'),
             'required': (Eval('type') != 'none') & Eval('company'),
             },
         depends=['company', 'type'])
-    credit_note_account = fields.Many2One('account.account', 'Credit Note Account',
+    credit_note_account = fields.Many2One('account.account',
+        'Credit Note Account',
         domain=[
             ('company', '=', Eval('company')),
-            ('kind', '!=', 'view'),
+            ('kind', 'not in', ['view', 'receivable', 'payable']),
             ],
         states={
             'readonly': (Eval('type') == 'none') | ~Eval('company'),
@@ -628,6 +621,7 @@ class Tax(ModelSQL, ModelView):
     invoice_base_sign = fields.Numeric('Invoice Base Sign', digits=(2, 0),
         help='Usualy 1 or -1',
         states={
+            'required': Eval('type') != 'none',
             'readonly': Eval('type') == 'none',
             }, depends=['type'])
     invoice_tax_code = fields.Many2One('account.tax.code',
@@ -638,6 +632,7 @@ class Tax(ModelSQL, ModelView):
     invoice_tax_sign = fields.Numeric('Invoice Tax Sign', digits=(2, 0),
         help='Usualy 1 or -1',
         states={
+            'required': Eval('type') != 'none',
             'readonly': Eval('type') == 'none',
             }, depends=['type'])
     credit_note_base_code = fields.Many2One('account.tax.code',
@@ -645,9 +640,10 @@ class Tax(ModelSQL, ModelView):
         states={
             'readonly': Eval('type') == 'none',
             }, depends=['type'])
-    credit_note_base_sign = fields.Numeric('Credit Note Base Sign', digits=(2, 0),
-        help='Usualy 1 or -1',
+    credit_note_base_sign = fields.Numeric('Credit Note Base Sign',
+        digits=(2, 0), help='Usualy 1 or -1',
         states={
+            'required': Eval('type') != 'none',
             'readonly': Eval('type') == 'none',
             }, depends=['type'])
     credit_note_tax_code = fields.Many2One('account.tax.code',
@@ -655,9 +651,10 @@ class Tax(ModelSQL, ModelView):
         states={
             'readonly': Eval('type') == 'none',
             }, depends=['type'])
-    credit_note_tax_sign = fields.Numeric('Credit Note Tax Sign', digits=(2, 0),
-        help='Usualy 1 or -1',
+    credit_note_tax_sign = fields.Numeric('Credit Note Tax Sign',
+        digits=(2, 0), help='Usualy 1 or -1',
         states={
+            'required': Eval('type') != 'none',
             'readonly': Eval('type') == 'none',
             }, depends=['type'])
     template = fields.Many2One('account.tax.template', 'Template')
@@ -696,7 +693,7 @@ class Tax(ModelSQL, ModelView):
         return Decimal('1')
 
     def default_company(self):
-        return Transaction().context.get('company') or False
+        return Transaction().context.get('company')
 
     def on_change_with_currency_digits(self, vals):
         company_obj = Pool().get('company.company')
@@ -787,8 +784,8 @@ class Tax(ModelSQL, ModelView):
 
         :param tax: a tax id or the BrowseRecord of the tax
         :param template2tax_code: a dictionary with tax code template id as key
-                and tax code id as value, used to convert tax code template into
-                tax code
+                and tax code id as value, used to convert tax code template
+                into tax code
         :param template2account: a dictionary with account template id as key
                 and account id as value, used to convert account template into
                 account code
@@ -807,71 +804,59 @@ class Tax(ModelSQL, ModelView):
 
         if tax.template:
             vals = template_obj._get_tax_value(tax.template, tax=tax)
-            if tax.template.invoice_account \
-                    and tax.invoice_account.id != \
-                    template2account.get(tax.template.invoice_account.id,
-                            False):
-                vals['invoice_account'] = \
-                        template2account.get(tax.template.invoice_account.id,
-                                False)
-            elif not tax.template.invoice_account \
-                    and tax.invoice_account:
-                vals['invoice_account'] =  False
-            if tax.template.credit_note_account \
-                    and tax.credit_note_account.id != \
-                    template2account.get(tax.template.credit_note_account.id,
-                            False):
-                vals['credit_note_account'] = \
-                        template2account.get(tax.template.credit_note_account.id,
-                                False)
-            elif not tax.template.credit_note_account \
-                    and tax.credit_note_account:
-                vals['credit_note_account'] = False
-            if tax.template.invoice_base_code \
-                    and tax.invoice_base_code.id != \
-                    template2tax_code.get(tax.template.invoice_base_code.id,
-                            False):
-                vals['invoice_base_code'] = \
-                        template2tax_code.get(tax.template.invoice_base_code.id,
-                                False)
-            elif not tax.template.invoice_base_code \
-                    and tax.invoice_base_code:
-                vals['invoice_base_code'] = False
-            if tax.template.invoice_tax_code \
-                    and tax.invoice_tax_code.id != \
-                    template2tax_code.get(tax.template.invoice_tax_code.id,
-                            False):
-                vals['invoice_tax_code'] = \
-                        template2tax_code.get(tax.template.invoice_tax_code.id,
-                                False)
-            elif not tax.template.invoice_tax_code \
-                    and tax.invoice_tax_code:
-                vals['invoice_tax_code'] = False
-            if tax.template.credit_note_base_code \
-                    and tax.credit_note_base_code.id != \
-                    template2tax_code.get(tax.template.credit_note_base_code.id,
-                            False):
-                vals['credit_note_base_code'] = \
-                        template2tax_code.get(tax.template.credit_note_base_code.id,
-                                False)
-            elif not tax.template.credit_note_base_code \
-                    and tax.credit_note_base_code:
-                vals['credit_note_base_code'] = False
-            if tax.template.credit_note_tax_code \
-                    and tax.credit_note_tax_code.id != \
-                    template2tax_code.get(tax.template.credit_note_tax_code.id,
-                            False):
-                vals['credit_note_tax_code'] = \
-                        template2tax_code.get(tax.template.credit_note_tax_code.id,
-                                False)
-            elif not tax.template.credit_note_tax_code \
-                    and tax.credit_note_tax_code:
-                vals['credit_note_tax_code'] = False
+            if (tax.template.invoice_account
+                    and tax.invoice_account.id != template2account.get(
+                        tax.template.invoice_account.id)):
+                vals['invoice_account'] = template2account.get(
+                    tax.template.invoice_account.id)
+            elif (not tax.template.invoice_account
+                    and tax.invoice_account):
+                vals['invoice_account'] = None
+            if (tax.template.credit_note_account
+                    and tax.credit_note_account.id != template2account.get(
+                        tax.template.credit_note_account.id)):
+                vals['credit_note_account'] = template2account.get(
+                    tax.template.credit_note_account.id)
+            elif (not tax.template.credit_note_account
+                    and tax.credit_note_account):
+                vals['credit_note_account'] = None
+            if (tax.template.invoice_base_code
+                    and tax.invoice_base_code.id != template2tax_code.get(
+                        tax.template.invoice_base_code.id)):
+                vals['invoice_base_code'] = template2tax_code.get(
+                    tax.template.invoice_base_code.id)
+            elif (not tax.template.invoice_base_code
+                    and tax.invoice_base_code):
+                vals['invoice_base_code'] = None
+            if (tax.template.invoice_tax_code
+                    and tax.invoice_tax_code.id != template2tax_code.get(
+                        tax.template.invoice_tax_code.id)):
+                vals['invoice_tax_code'] = template2tax_code.get(
+                    tax.template.invoice_tax_code.id)
+            elif (not tax.template.invoice_tax_code
+                    and tax.invoice_tax_code):
+                vals['invoice_tax_code'] = None
+            if (tax.template.credit_note_base_code
+                    and tax.credit_note_base_code.id != template2tax_code.get(
+                        tax.template.credit_note_base_code.id)):
+                vals['credit_note_base_code'] = template2tax_code.get(
+                    tax.template.credit_note_base_code.id)
+            elif (not tax.template.credit_note_base_code
+                    and tax.credit_note_base_code):
+                vals['credit_note_base_code'] = None
+            if (tax.template.credit_note_tax_code
+                    and tax.credit_note_tax_code.id != template2tax_code.get(
+                        tax.template.credit_note_tax_code.id)):
+                vals['credit_note_tax_code'] = template2tax_code.get(
+                    tax.template.credit_note_tax_code.id)
+            elif (not tax.template.credit_note_tax_code
+                    and tax.credit_note_tax_code):
+                vals['credit_note_tax_code'] = None
 
             if vals:
                 self.write(tax.id, vals)
 
-            prev_lang = tax._context.get('language') or 'en_US'
+            prev_lang = tax._context.get('language') or CONFIG['language']
             prev_data = {}
             for field_name, field in tax.template._columns.iteritems():
                 if getattr(field, 'translate', False):
@@ -908,12 +893,13 @@ class Line(ModelSQL, ModelView):
     currency_digits = fields.Function(fields.Integer('Currency Digits',
         on_change_with=['move_line']), 'get_currency_digits')
     amount = fields.Numeric('Amount', digits=(16, Eval('currency_digits', 2)),
-            depends=['currency_digits'])
-    code = fields.Many2One('account.tax.code', 'Code', select=1, required=True)
-    tax = fields.Many2One('account.tax', 'Tax', select=1, ondelete='RESTRICT',
-            on_change=['tax'])
+        required=True, depends=['currency_digits'])
+    code = fields.Many2One('account.tax.code', 'Code', select=True,
+        required=True)
+    tax = fields.Many2One('account.tax', 'Tax', select=True,
+        ondelete='RESTRICT', on_change=['tax'])
     move_line = fields.Many2One('account.move.line', 'Move Line',
-            required=True, select=1, ondelete='CASCADE')
+            required=True, select=True, ondelete='CASCADE')
 
     def on_change_with_currency_digits(self, vals):
         move_line_obj = Pool().get('account.move.line')
@@ -930,7 +916,7 @@ class Line(ModelSQL, ModelView):
 
     def on_change_tax(self, vals):
         res = {
-            'code': False,
+            'code': None,
             }
         return res
 
@@ -944,7 +930,7 @@ class RuleTemplate(ModelSQL, ModelView):
     name = fields.Char('Name', required=True, translate=True)
     lines = fields.One2Many('account.tax.rule.line.template', 'rule', 'Lines')
     account = fields.Many2One('account.account.template', 'Account Template',
-            domain=[('parent', '=', False)], required=True)
+            domain=[('parent', '=', None)], required=True)
 
     def _get_tax_rule_value(self, template, rule=None):
         '''
@@ -988,7 +974,7 @@ class RuleTemplate(ModelSQL, ModelView):
             vals['company'] = company_id
             new_id = rule_obj.create(vals)
 
-            prev_lang = template._context.get('language') or 'en_US'
+            prev_lang = template._context.get('language') or CONFIG['language']
             prev_data = {}
             for field_name, field in template._columns.iteritems():
                 if getattr(field, 'translate', False):
@@ -1020,7 +1006,7 @@ class Rule(ModelSQL, ModelView):
     _description = __doc__
     name = fields.Char('Name', required=True, translate=True)
     company = fields.Many2One('company.company', 'Company', required=True,
-        select=1, domain=[
+        select=True, domain=[
             ('id', If(Eval('context', {}).contains('company'), '=', '!='),
                 Eval('context', {}).get('company', 0)),
             ])
@@ -1035,7 +1021,7 @@ class Rule(ModelSQL, ModelView):
         :param tax: a tax id or the BrowseRecord of the tax
         :param pattern: a dictonary with rule line field as key
                 and match value as value
-        :return: a list of the tax id to use or False
+        :return: a list of the tax id to use or None
         '''
         tax_obj = Pool().get('account.tax')
         rule_line_obj = Pool().get('account.tax.rule.line')
@@ -1047,13 +1033,13 @@ class Rule(ModelSQL, ModelView):
             tax = tax_obj.browse(tax)
 
         pattern = pattern.copy()
-        pattern['group'] = tax and tax.group.id or False
-        pattern['origin_tax'] = tax and tax.id or False
+        pattern['group'] = tax and tax.group.id or None
+        pattern['origin_tax'] = tax and tax.id or None
 
         for line in rule.lines:
             if rule_line_obj.match(line, pattern):
                 return rule_line_obj.get_taxes(line)
-        return tax and [tax.id] or False
+        return tax and [tax.id] or None
 
     def update_rule(self, rule, template2rule=None):
         '''
@@ -1078,7 +1064,7 @@ class Rule(ModelSQL, ModelView):
             if vals:
                 self.write(rule.id, vals)
 
-            prev_lang = rule._context.get('language') or 'en_US'
+            prev_lang = rule._context.get('language') or CONFIG['language']
             prev_data = {}
             for field_name, field in rule.template._columns.iteritems():
                 if getattr(field, 'translate', False):
@@ -1123,7 +1109,7 @@ class RuleLineTemplate(ModelSQL, ModelView):
             ('group', '=', Eval('group')),
             ],
         depends=['group'])
-    sequence = fields.Integer('Sequence')
+    sequence = fields.Integer('Sequence', required=True)
 
     def __init__(self):
         super(RuleLineTemplate, self).__init__()
@@ -1182,11 +1168,11 @@ class RuleLineTemplate(ModelSQL, ModelView):
             if template.origin_tax:
                 vals['origin_tax'] = template2tax[template.origin_tax.id]
             else:
-                vals['origin_tax'] = False
+                vals['origin_tax'] = None
             if template.tax:
                 vals['tax'] = template2tax[template.tax.id]
             else:
-                vals['tax'] = False
+                vals['tax'] = None
             new_id = rule_line_obj.create(vals)
             template2rule_line[template.id] = new_id
         else:
@@ -1202,7 +1188,7 @@ class RuleLine(ModelSQL, ModelView):
     _description = __doc__
     _rec_name = 'tax'
     rule = fields.Many2One('account.tax.rule', 'Rule', required=True,
-            select=1, ondelete='CASCADE')
+            select=True, ondelete='CASCADE')
     group = fields.Many2One('account.tax.group', 'Tax Group')
     origin_tax = fields.Many2One('account.tax', 'Original Tax',
         domain=[
@@ -1218,7 +1204,7 @@ class RuleLine(ModelSQL, ModelView):
             ('group', '=', Eval('group')),
             ],
         depends=['group'])
-    sequence = fields.Integer('Sequence')
+    sequence = fields.Integer('Sequence', required=True)
     template = fields.Many2One('account.tax.rule.line.template', 'Template')
 
     def __init__(self):
@@ -1260,7 +1246,7 @@ class RuleLine(ModelSQL, ModelView):
         '''
         if line.tax:
             return [line.tax.id]
-        return False
+        return None
 
     def update_rule_line(self, rule_line, template2tax, template2rule,
             template2rule_line=None):
@@ -1313,20 +1299,11 @@ RuleLine()
 class OpenCode(Wizard):
     'Open Code'
     _name = 'account.tax.open_code'
-    states = {
-        'init': {
-            'result': {
-                'type': 'action',
-                'action': '_action_open_code',
-                'state': 'end',
-            },
-        },
-    }
+    start_state = 'open_'
+    open_ = StateAction('account.act_tax_line_form')
 
-    def _action_open_code(self, data):
+    def do_open_(self, session, action):
         pool = Pool()
-        model_data_obj = pool.get('ir.model.data')
-        act_window_obj = pool.get('ir.action.act_window')
         fiscalyear_obj = pool.get('account.fiscalyear')
         period_obj = pool.get('account.period')
 
@@ -1345,21 +1322,19 @@ class OpenCode(Wizard):
         else:
             period_ids = Transaction().context['periods']
 
-        act_window_id = model_data_obj.get_id('account', 'act_tax_line_form')
-        res = act_window_obj.read(act_window_id)
-        res['pyson_domain'] = PYSONEncoder().encode([
-            ('move_line.period', 'in', period_ids),
-            ('code', '=', data['id']),
-            ])
+        action['pyson_domain'] = PYSONEncoder().encode([
+                ('move_line.period', 'in', period_ids),
+                ('code', '=', Transaction().context['active_id']),
+                ])
         if Transaction().context.get('fiscalyear'):
-            res['pyson_context'] = PYSONEncoder().encode({
-                'fiscalyear': Transaction().context['fiscalyear'],
-            })
+            action['pyson_context'] = PYSONEncoder().encode({
+                    'fiscalyear': Transaction().context['fiscalyear'],
+                    })
         else:
-            res['pyson_context'] = PYSONEncoder().encode({
-                'periods': period_ids,
-            })
-        return res
+            action['pyson_context'] = PYSONEncoder().encode({
+                    'periods': period_ids,
+                    })
+        return action, {}
 
 OpenCode()
 
@@ -1370,9 +1345,9 @@ class AccountTemplateTaxTemplate(ModelSQL):
     _table = 'account_account_template_tax_rel'
     _description = __doc__
     account = fields.Many2One('account.account.template', 'Account Template',
-            ondelete='CASCADE', select=1, required=True)
+            ondelete='CASCADE', select=True, required=True)
     tax = fields.Many2One('account.tax.template', 'Tax Template',
-            ondelete='RESTRICT', select=1, required=True)
+            ondelete='RESTRICT', select=True, required=True)
 
 AccountTemplateTaxTemplate()
 
@@ -1381,7 +1356,7 @@ class AccountTemplate(ModelSQL, ModelView):
     _name = 'account.account.template'
     taxes = fields.Many2Many('account.account.template-account.tax.template',
             'account', 'tax', 'Default Taxes',
-            domain=[('parent', '=', False)])
+            domain=[('parent', '=', None)])
 
 AccountTemplate()
 
@@ -1392,9 +1367,9 @@ class AccountTax(ModelSQL):
     _table = 'account_account_tax_rel'
     _description = __doc__
     account = fields.Many2One('account.account', 'Account', ondelete='CASCADE',
-            select=1, required=True)
+            select=True, required=True)
     tax = fields.Many2One('account.tax', 'Tax', ondelete='RESTRICT',
-            select=1, required=True)
+            select=True, required=True)
 
 AccountTax()
 
@@ -1405,7 +1380,7 @@ class Account(ModelSQL, ModelView):
             'account', 'tax', 'Default Taxes',
             domain=[
                 ('company', '=', Eval('company')),
-                ('parent', '=', False),
+                ('parent', '=', None),
             ],
             help='Default tax for manual encoding of move lines \n' \
                     'for journal types: "expense" and "revenue"',
